@@ -615,11 +615,11 @@ sub feed_map1a {
 
    if ($delay) {
       # delay the map drawing a tiny bit in the hope of getting the missing fetched
-      Event->timer (after => 0.03, cb => sub {
-         $_[0]->w->cancel;
+      my $delay_draw; $delay_draw = EV::timer 0.03, 0, sub {
+         undef $delay_draw;
          $self->{map_widget}->update
             if $self->{map_widget};
-      });
+      };
    } else {
       $self->{map_widget}->update;
    }
